import { createFileSystemReader } from '@previewjs/vfs';
import createLogger from 'pino';
import prettyLogger from 'pino-pretty';

function factoryWithDefaultOptions(factory) {
  return (options) => factory({
    ...options,
    reader: options.reader || createFileSystemReader(),
    logger: options.logger || createLogger({ level: "debug" }, prettyLogger({ colorize: true }))
  });
}

function generatePreviewableId(options) {
  return `${options.filePath.replace(/\\/g, "/")}:${options.name}`;
}
function decodePreviewableId(id) {
  const colonPosition = id.lastIndexOf(":");
  if (colonPosition === -1) {
    throw new Error(`Invalid previewable ID: "${id}"`);
  }
  const [filePath, name] = id.split(":");
  return {
    filePath,
    name
  };
}

export { decodePreviewableId, factoryWithDefaultOptions, generatePreviewableId };
